@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from quokka import app
 from flask.ext.mongoengine import MongoEngine
-db = MongoEngine(app)
+from .fields import ListField
+
+db = MongoEngine()
+db.ListField = ListField
