@@ -6,5 +6,5 @@ from quokka.core.models import Content
 
 
 class Post(Content):
-    URL_NAMESPACE = 'posts.detail'
+    # URL_NAMESPACE = 'posts.detail'
     body = db.StringField(required=True)
